Installing PDF/PNG Export Functionality

## PDF/PNG Export

Export to PDF and PNG file formats requires the LibRSVG (SVG rendering) library to be installed.

### Mac OS X

1. Install homebrew: follow the one-step installation directions here to install homebrew, the OS X package manager.
2. Install librsvg using homebrew: run the following command to install librsvg:

       brew install librsvg

### Linux (Ubuntu or similar)

1. Install librsvg: run the following command to install librsvg on ubuntu/debian/similar:

       sudo apt-get install librsvg2-dev